flutter_stasis_core library

Classes

Command<F, R>
Unit of executable work that returns CommandResult.
CommandAction
Encapsulates command execution flow for async stasis results.
CommandExecutionScope
Mutable execution context used by command policies.
CommandFailure<F, R>
Failed command output.
CommandResult<F, R>
Result contract for command execution independent from external FP libs.
CommandSuccess<F, R>
Successful command output.
ErrorState<F, S>
Error state with failure.
InitialState<F, S>
Initial state.
LoadingState<F, S>
Loading state.
MappedCommand<F, I, O>
Decorates a command by mapping the successful value.
StateFailure
Base failure contract used by stasis command/state abstractions.
StateObject<F, S, Self extends StateObject<F, S, Self>>
Immutable state object owned by a single view model/screen.
SuccessState<F, S>
Success state with data.
TaskCommand<F, R>
Adapts a function into a Command.
ViewModelState<F, S>
Canonical state lifecycle used by view models.

Enums

CommandPolicy
Concurrency strategy used while executing commands.

Extensions

CommandMapX on Command<F, R>
Helpers for command composition.