ErrorState<F, S> class
final
Error state with failure.
- Inheritance
-
- Object
- ViewModelState<
F, S> - ErrorState
Constructors
- ErrorState(F failure)
-
const
Properties
- actualState → InternalState
-
Explicit lifecycle discriminant for this state instance.
no setterinherited
- failure → F
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
-
when<
T> ({required T initial(), required T loading(), required T success(S data), required T error(F failure)}) → T -
Exhaustive handling for all state variants.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited